diff src/fileio.c @ 14036:621a575db6f7

Comment fixes.
author Karl Heuer <kwzh@gnu.org>
date Fri, 05 Jan 1996 10:03:17 +0000
parents 31e37f3d8ccd
children f15db8536fdd
line wrap: on
line diff
--- a/src/fileio.c	Fri Jan 05 08:57:33 1996 +0000
+++ b/src/fileio.c	Fri Jan 05 10:03:17 1996 +0000
@@ -2936,7 +2936,7 @@
 		 && FETCH_CHAR (same_at_start) == buffer[bufpos])
 	    same_at_start++, bufpos++;
 	  /* If we found a discrepancy, stop the scan.
-	     Otherwise loop around and scan the next bufferfull.  */
+	     Otherwise loop around and scan the next bufferful.  */
 	  if (bufpos != nread)
 	    break;
 	}
@@ -2979,7 +2979,7 @@
 		       XSTRING (filename)->data, strerror (errno));
 	      total_read += nread;
 	    }
 	  /* Scan this bufferfull from the end, comparing with
 	     the Emacs buffer.  */
 	  bufpos = total_read;
 	  /* Compare with same_at_start to avoid counting some buffer text
@@ -2988,7 +2988,7 @@
 		 && FETCH_CHAR (same_at_end - 1) == buffer[bufpos - 1])
 	    same_at_end--, bufpos--;
 	  /* If we found a discrepancy, stop the scan.
-	     Otherwise loop around and scan the preceding bufferfull.  */
+	     Otherwise loop around and scan the preceding bufferful.  */
 	  if (bufpos != 0)
 	    break;
 	  /* If display current starts at beginning of line,
@@ -2979,7 +2979,7 @@
 	      total_read += nread;
 	    }
-	  /* Scan this bufferfull from the end, comparing with
+	  /* Scan this bufferful from the end, comparing with
 	     the Emacs buffer.  */
 	  bufpos = total_read;